/// <reference types="node" />
import { EventEmitter } from "events";
import { IProvider } from "../interfaces/IProvider";
import { IClientConfig } from "../interfaces/IClientConfig";
import { IAccount } from "../interfaces/IAccount";
import { IContractData } from "../interfaces/IContractData";
import { JsonRpcResponseData } from "../interfaces/JsonRpcResponseData";
import { IStatus } from "../interfaces/IStatus";
import { IAddressInfo } from "../interfaces/IAddressInfo";
export declare class Client extends EventEmitter {
    private clientConfig;
    private baseAccount;
    constructor(clientConfig: IClientConfig, baseAccount?: IAccount);
    getPrivateProviders(): Array<IProvider>;
    getPublicProviders(): Array<IProvider>;
    private getProviderForRpcMethod;
    setBaseAccount(baseAccount: IAccount): void;
    getBaseAccount(): IAccount;
    private sendJsonRPCRequest;
    executeSC<T>(contractData: IContractData, executor?: IAccount): Promise<JsonRpcResponseData<T>>;
    private signOperation;
    private computeBytesCompact;
    unbanIpAddress(ipAddress: string): Promise<void>;
    banIpAddress(ipAddress: string): Promise<void>;
    nodeStop(): Promise<void>;
    nodeGetStakingAddresses(): Promise<Array<string>>;
    nodeRemoveStakingAddresses(addresses: Array<string>): Promise<void>;
    nodeAddStakingPrivateKeys(privateKeys: Array<string>): Promise<void>;
    getStatus(): Promise<IStatus>;
    getAddresses(addresses: Array<string>): Promise<Array<IAddressInfo>>;
    getBlocks: (blockIds: any) => void;
    getEndorsements: (endorsementIds: any) => void;
    getOperations: (operationIds: any) => void;
    buyRolls: (address: any, rollCount: any, fee: any) => void;
    sellRolls: (address: any, rollCount: any, fee: any) => void;
    sendTransaction: (senderAddress: any, receiverAddress: any, amount: any, fee: any) => void;
    sendSmartContract: (senderAddress: any, bytecode: any, maxGas: any, gasPrice: any, coins: any, fee: any) => void;
    readonlySmartContract: (bytecode: any, maxGas: any, gasPrice: any, address: any) => void;
    walletInfo: () => void;
    walletGeneratePrivateKey: () => void;
    walletAddPrivateKeys: (privateKeys: any) => void;
    walletRemoveAddresses: (addresses: any) => void;
    walletSign: (address: any, string: any) => void;
}
